@@ -17,7 +17,7 @@
 use 5.008003;
 package YamlTime;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Requires
 BEGIN { $ENV{PERL_RL} = 'Gnu o=0' }
@@ -33,6 +33,7 @@ use Template::Toolkit::Simple 0.13 ();
 use Template::Plugin::YAMLVal 0.10 ();
 use Term::ReadLine 1.07 ();
 use Text::CSV_XS 0.82 ();
+use Text::ParseWords 3.27 ();
 use YAML::XS 0.35 ();
 my $requires = "
 use Term::ReadLine::Gnu 1.20 ();
@@ -116,7 +117,11 @@ our $Conf;
 # App::Cmd help helpers
 use constant usage => 'YamlTime';
 use constant text => "yt command [<options>] [<arguments>]\n";
-use constant default_command => $ENV{YAMLTIME_DEFAULT_COMMAND} || 'status';
+
+sub default_args {
+    my $default = $ENV{YAMLTIME_DEFAULT_ARGS} or return [];
+    return [ Text::ParseWords::shellwords($default) ];
+}
 
 #-----------------------------------------------------------------------------#
 # A role for time/tag range options
